API docs for “spamfighter.core.commands.apiglue.XMLRPC_API_Glue”

# Class s.c.c.a.XMLRPC_API_Glue(xmlrpc.XMLRPC, API_Glue):

Part of spamfighter.core.commands.apiglue View Source View In Hierarchy

Ресурс XML-RPC (Twisted Web), который обрабатывает команды нашего API (минуя стандартные механизмы поиска функции).

Method | _getFunction | Undocumented

Inherited from API_Glue:

Method | _internalGetFunction | Получить функцию, выполняющую команду с указанным именем и при этом

@xmlrpc_error_translator
def _getFunction(self, functionPath): (source)
Undocumented